===========
IsItPangram
===========


.. image:: https://img.shields.io/pypi/v/isitpangram.svg
        :target: https://pypi.python.org/pypi/isitpangram

.. image:: https://img.shields.io/travis/fertek/isitpangram.svg
        :target: https://travis-ci.org/fertek/isitpangram

.. image:: https://readthedocs.org/projects/isitpangram/badge/?version=latest
        :target: https://isitpangram.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A function to determine if a sentence is a pangram.

A pangram (Greek: παν γράμμα, pan gramma, "every letter") is a sentence using every letter of the alphabet at least once.

The best known English pangram is: *The quick brown fox jumps over the lazy dog.*


* Free software: MIT license
* Documentation: https://isitpangram.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
